/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import { Component, OnInit } from '@angular/core';
import { NotificationsService } from '../../services/notifications.service';
import {JsonObject} from "@angular/compiler-cli/ngcc/src/packages/entry_point";

@Component({
  selector: 'app-email-templates',
  templateUrl: './email-templates.component.html',
  styleUrls: ['./email-templates.component.scss']
})
export class EmailTemplatesComponent implements OnInit {
  emailTemplates: any

  constructor(private notificationsService: NotificationsService) { }

  ngOnInit(): void {
    this.getEmailTemplates()
  }

  getEmailTemplates() {
    const emailTemplatesObserver = {
      next: (request) => {
        this.emailTemplates = request;
      },
      error: (error) => console.error("Error when retrieving list of email templates:" + error),
    };
    this.notificationsService.getEmailTemplates().subscribe(emailTemplatesObserver);
  }

  submitEmailTemplateEdit(editsToSubmit: JsonObject){
    const editEmailTemplatesObserver = {
      next: (request) => {
        this.getEmailTemplates()
      },
      error: (error) => {
        console.error("Error when updating email template:", error)
        this.getEmailTemplates()
      }
    };
    this.notificationsService.updateEmailTemplates(editsToSubmit).subscribe(editEmailTemplatesObserver);
  }

}
